# NOTE:
# f.d.o source is meant to be a more Linux packaging friendly copy of the
# AudioProcessing module from the WebRTC[1] project. The ideal case is that we
# make no changes to the code to make tracking upstream code easy.
# [1] http://code.google.com/p/webrtc/
#
# Conditional build:
%bcond_without	neon		# ARM NEON instructions
%bcond_with	sse2		# SSE2 instructions

%ifnarch armv7hnl armv8l armv8hl armv8hnl armv8hcnl aarch64
%undefine	with_neon
%endif
%ifarch pentium4 %{x8664} x32
%define		with_sse2	1
%endif

Summary:	WebRTC Audio Processing library
Summary(pl.UTF-8):	Biblioteka WebRTC Audio Processing
Name:		webrtc-audio-processing1
Version:	1.3
Release:	1
License:	BSD
Group:		Libraries
Source0:	https://freedesktop.org/software/pulseaudio/webrtc-audio-processing/webrtc-audio-processing-%{version}.tar.gz
# Source0-md5:	743bf4f5c7132560b1af33aaa0129228
Patch0:		%{name}-nosimd.patch
URL:		https://www.freedesktop.org/software/pulseaudio/webrtc-audio-processing/
BuildRequires:	abseil-cpp-devel >= 20200923
BuildRequires:	libstdc++-devel >= 6:5
BuildRequires:	meson >= 0.63
BuildRequires:	ninja >= 1.5
BuildRequires:	pkgconfig
BuildRequires:	rpmbuild(macros) >= 1.736
BuildRoot:	%{tmpdir}/%{name}-%{version}-root-%(id -u -n)

%description
WebRTC is an open source project that enables web browsers with
Real-Time Communications (RTC) capabilities via simple Javascript
APIs. The WebRTC components have been optimized to best serve this
purpose. WebRTC implements the W3C's proposal for video conferencing
on the web.

%description -l pl.UTF-8
WebRTC to projekt o otwartych źródłach dodający obsługę komunikacji
w czasie rzeczywistym (RTC - Real-Time Communications) poprzez proste
API JavaScriptu. Komponenty WebRTC zostały zoptymalizowane, aby jak
najlepiej sprawdzały się w tym zastosowaniu. WebRTC implementuje
propozycje W3C do wideokonferencji w sieci.

%package devel
Summary:	Header files for WebRTC Audio Processing library
Summary(pl.UTF-8):	Pliki nagłówkowe biblioteki WebRTC Audio Processing
Group:		Development/Libraries
Requires:	%{name} = %{version}-%{release}
Requires:	abseil-cpp-devel >= 20200923
Requires:	libstdc++-devel >= 6:5

%description devel
This package contains the header files needed to develop programs
which make use of WebRTC Audio Processing library.

%description devel -l pl.UTF-8
Ten pakiet zawiera pliki nagłówkowe potrzebne do tworzenia programów
wykorzystujących bibliotekę WebRTC Audio Processing.

%package static
Summary:	Static WebRTC Audio Processing library
Summary(pl.UTF-8):	Biblioteka statyczna WebRTC Audio Processing
Group:		Development/Libraries
Requires:	%{name}-devel = %{version}-%{release}

%description static
Static WebRTC Audio Processing library.

%description static -l pl.UTF-8
Biblioteka statyczna WebRTC Audio Processing.

%prep
%setup -q -n webrtc-audio-processing-%{version}
%patch0 -p1

%ifarch %{ix86}
%if %{without sse2}
# add -DPFFFT_SIMD_DISABLE
%{__sed} -i -e 's/have_arm and not have_neon.*/& or true/' webrtc/third_party/pffft/meson.build
%endif
%endif

%build
%if %{with sse2}
CFLAGS="%{rpmcflags} -msse2"
CXXFLAGS="%{rpmcxxflags} -msse2"
%endif
%meson build \
	-Dneon=%{?with_neon:yes}%{!?with_neon:no}

%ninja_build -C build

%install
rm -rf $RPM_BUILD_ROOT

%ninja_install -C build

%clean
rm -rf $RPM_BUILD_ROOT

%post	-p /sbin/ldconfig
%postun	-p /sbin/ldconfig

%files
%defattr(644,root,root,755)
%doc AUTHORS COPYING NEWS README.md webrtc/PATENTS
%attr(755,root,root) %{_libdir}/libwebrtc-audio-coding-1.so.3
%attr(755,root,root) %{_libdir}/libwebrtc-audio-processing-1.so.3

%files devel
%defattr(644,root,root,755)
%attr(755,root,root) %{_libdir}/libwebrtc-audio-coding-1.so
%attr(755,root,root) %{_libdir}/libwebrtc-audio-processing-1.so
%{_includedir}/webrtc-audio-processing-1
%{_pkgconfigdir}/webrtc-audio-coding-1.pc
%{_pkgconfigdir}/webrtc-audio-processing-1.pc

%files static
%defattr(644,root,root,755)
%{_libdir}/libwebrtc-audio-coding-1.a
%{_libdir}/libwebrtc-audio-processing-1.a
%changelog
* Fri Sep 15 2023 PLD Linux Team <feedback@pld-linux.org>
- For complete changelog see: http://git.pld-linux.org/?p=packages/webrtc-audio-processing1.git;a=log;h=master

* Thu Sep 14 2023 Jan Palus <atler@pld-linux.org> c7f1a5f
- neon runtime detection is effectively gone

* Thu Sep 14 2023 Jan Palus <atler@pld-linux.org> 6d539b6
- up to 1.3 (new sonames)

* Thu Apr 06 2023 Jakub Bogusz <qboosh@pld-linux.org> 1f7a177
- release 6 (abseil LTS 20220623)

* Sat May 21 2022 Jan Palus <jpalus@fastmail.com> 9e7567d
- macros for %ninja*

* Sat May 21 2022 Jan Palus <jpalus@fastmail.com> e42bc18
- exclude aarch64 from neon bcond

* Wed Feb 16 2022 Jan Rękorajski <baggins@pld-linux.org> 762ee6d
- Release 5 (by relup.sh)

* Fri Dec 03 2021 Jan Rękorajski <baggins@pld-linux.org> e0a7261
- abseil needs c++17 now, rel 4

* Mon Nov 29 2021 Jan Rękorajski <baggins@pld-linux.org> 452b108
- Release 3 (by relup.sh)

* Sat Nov 20 2021 Jan Rękorajski <baggins@pld-linux.org> bffe50f
- rebuild with separate debuginfo build-ids

* Sun Mar 14 2021 Jakub Bogusz <qboosh@pld-linux.org> 6f2a5c0
- webrtc-audio-processing updated to 1.0 (parallel installable with webrtc-audio-processing 0.x)
- added abseil patch to fix/adjust abseil library name
- added nosimd patch to fix build for x86 without SSE2

* Fri Dec 04 2020 Jan Palus <atler@pld-linux.org> 902b8ee
- disable neon on not applicable archs

* Wed Oct 17 2018 Jakub Bogusz <qboosh@pld-linux.org> 7e62f71
- updated to 0.3.1

* Fri Jun 24 2016 Jakub Bogusz <qboosh@pld-linux.org> 97029a0
- updated URLs, require gcc/libstdc++ 4.7 (for -std=c++11)

* Thu Jun 23 2016 Jan Palus <atler@pld-linux.org> 6da3638
- up to 0.3

* Tue Feb 24 2015 Jan Rękorajski <baggins@pld-linux.org> 5e8e5d7
- x32 rebuild
- release 2 (by relup.sh)

* Tue May 22 2012 Jakub Bogusz <qboosh@pld-linux.org> 1a9d4a7
- added -static
- pl
- devel R: libstdc++-devel

* Wed May 16 2012 Elan Ruusamäe <glen@pld-linux.org> ac8de86
- new, based on altlinux package
- NOTE: This is basically a fork of AudioProcessing module from the WebRTC project

